@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Radicale Server - Calendar Server
-# Copyright © 2012 Guillaume Ayoub
+# Copyright © 2012-2013 Guillaume Ayoub
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,13 +23,20 @@ This module loads the storage backend, according to the storage
 configuration.
 
 """
-
-from radicale import config
+import sys
+from .. import config, ical
 
 
 def load():
     """Load list of available storage managers."""
     storage_type = config.get("storage", "type")
-    module = __import__(
-        "storage.%s" % storage_type, globals=globals(), level=2)
-    return getattr(module, storage_type)
+    if storage_type == "custom":
+        storage_module = config.get("storage", "custom_handler")
+        __import__(storage_module)
+        module = sys.modules[storage_module]
+    else:
+        root_module = __import__(
+            "storage.%s" % storage_type, globals=globals(), level=2)
+        module = getattr(root_module, storage_type)
+    ical.Collection = module.Collection
+    return module
